==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/wsdl/model/TDefinitions.java <==

package org.somda.sdc.dpws.wsdl.model;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for tDefinitions complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="tDefinitions"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schemas.xmlsoap.org/wsdl/}tExtensibleDocumented"&gt;
 *       &lt;sequence&gt;
 *         &lt;group ref="{http://schemas.xmlsoap.org/wsdl/}anyTopLevelOptionalElement" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="targetNamespace" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}NCName" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "tDefinitions", namespace = "http://schemas.xmlsoap.org/wsdl/", propOrder = {
    "anyTopLevelOptionalElement"
})
public class TDefinitions
    extends TExtensibleDocumented
    implements ToString2
{

    @XmlElements({
        @XmlElement(name = "import", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TImport.class),
        @XmlElement(name = "types", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TTypes.class),
        @XmlElement(name = "message", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TMessage.class),
        @XmlElement(name = "portType", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TPortType.class),
        @XmlElement(name = "binding", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TBinding.class),
        @XmlElement(name = "service", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TService.class)
    })
    protected List<TDocumented> anyTopLevelOptionalElement;
    @XmlAttribute(name = "targetNamespace")
    @XmlSchemaType(name = "anyURI")
    protected String targetNamespace;
    @XmlAttribute(name = "name")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String name;

    /**
     * Gets the value of the anyTopLevelOptionalElement property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the anyTopLevelOptionalElement property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAnyTopLevelOptionalElement().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TImport }
     * {@link TTypes }
     * {@link TMessage }
     * {@link TPortType }
     * {@link TBinding }
     * {@link TService }
     * 
     * 
     */
    public List<TDocumented> getAnyTopLevelOptionalElement() {
        if (anyTopLevelOptionalElement == null) {
            anyTopLevelOptionalElement = new ArrayList<TDocumented>();
        }
        return this.anyTopLevelOptionalElement;
    }

    /**
     * Ruft den Wert der targetNamespace-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetNamespace() {
        return targetNamespace;
    }

    /**
     * Legt den Wert der targetNamespace-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetNamespace(String value) {
        this.targetNamespace = value;
    }

    /**
     * Ruft den Wert der name-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Legt den Wert der name-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    public void setAnyTopLevelOptionalElement(List<TDocumented> value) {
        this.anyTopLevelOptionalElement = null;
        if (value!= null) {
            List<TDocumented> draftl = this.getAnyTopLevelOptionalElement();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(object)) {
            return false;
        }
        final TDefinitions that = ((TDefinitions) object);
        {
            List<TDocumented> leftAnyTopLevelOptionalElement;
            leftAnyTopLevelOptionalElement = (((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty()))?this.getAnyTopLevelOptionalElement():null);
            List<TDocumented> rightAnyTopLevelOptionalElement;
            rightAnyTopLevelOptionalElement = (((that.anyTopLevelOptionalElement!= null)&&(!that.anyTopLevelOptionalElement.isEmpty()))?that.getAnyTopLevelOptionalElement():null);
            if ((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty())) {
                if ((that.anyTopLevelOptionalElement!= null)&&(!that.anyTopLevelOptionalElement.isEmpty())) {
                    if (!leftAnyTopLevelOptionalElement.equals(rightAnyTopLevelOptionalElement)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.anyTopLevelOptionalElement!= null)&&(!that.anyTopLevelOptionalElement.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftTargetNamespace;
            leftTargetNamespace = this.getTargetNamespace();
            String rightTargetNamespace;
            rightTargetNamespace = that.getTargetNamespace();
            if (this.targetNamespace!= null) {
                if (that.targetNamespace!= null) {
                    if (!leftTargetNamespace.equals(rightTargetNamespace)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.targetNamespace!= null) {
                    return false;
                }
            }
        }
        {
            String leftName;
            leftName = this.getName();
            String rightName;
            rightName = that.getName();
            if (this.name!= null) {
                if (that.name!= null) {
                    if (!leftName.equals(rightName)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.name!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        currentHashCode = ((currentHashCode* 31)+ super.hashCode());
        {
            currentHashCode = (currentHashCode* 31);
            List<TDocumented> theAnyTopLevelOptionalElement;
            theAnyTopLevelOptionalElement = (((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty()))?this.getAnyTopLevelOptionalElement():null);
            if ((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty())) {
                currentHashCode += theAnyTopLevelOptionalElement.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theTargetNamespace;
            theTargetNamespace = this.getTargetNamespace();
            if (this.targetNamespace!= null) {
                currentHashCode += theTargetNamespace.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theName;
            theName = this.getName();
            if (this.name!= null) {
                currentHashCode += theName.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<TDocumented> theAnyTopLevelOptionalElement;
            theAnyTopLevelOptionalElement = (((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty()))?this.getAnyTopLevelOptionalElement():null);
            strategy.appendField(locator, this, "anyTopLevelOptionalElement", buffer, theAnyTopLevelOptionalElement, ((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty())));
        }
        {
            String theTargetNamespace;
            theTargetNamespace = this.getTargetNamespace();
            strategy.appendField(locator, this, "targetNamespace", buffer, theTargetNamespace, (this.targetNamespace!= null));
        }
        {
            String theName;
            theName = this.getName();
            strategy.appendField(locator, this, "name", buffer, theName, (this.name!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/wsdl/model/TDefinitions.java <==

package org.somda.sdc.dpws.wsdl.model;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for tDefinitions complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="tDefinitions"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schemas.xmlsoap.org/wsdl/}tExtensibleDocumented"&gt;
 *       &lt;sequence&gt;
 *         &lt;group ref="{http://schemas.xmlsoap.org/wsdl/}anyTopLevelOptionalElement" maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="targetNamespace" type="{http://www.w3.org/2001/XMLSchema}anyURI" /&gt;
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}NCName" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "tDefinitions", namespace = "http://schemas.xmlsoap.org/wsdl/", propOrder = {
    "anyTopLevelOptionalElement"
})
public class TDefinitions
    extends TExtensibleDocumented
    implements ToString2
{

    @XmlElements({
        @XmlElement(name = "import", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TImport.class),
        @XmlElement(name = "types", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TTypes.class),
        @XmlElement(name = "message", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TMessage.class),
        @XmlElement(name = "portType", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TPortType.class),
        @XmlElement(name = "binding", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TBinding.class),
        @XmlElement(name = "service", namespace = "http://schemas.xmlsoap.org/wsdl/", type = TService.class)
    })
    protected List<TDocumented> anyTopLevelOptionalElement;
    @XmlAttribute(name = "targetNamespace")
    @XmlSchemaType(name = "anyURI")
    protected String targetNamespace;
    @XmlAttribute(name = "name")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlSchemaType(name = "NCName")
    protected String name;

    /**
     * Gets the value of the anyTopLevelOptionalElement property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the anyTopLevelOptionalElement property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAnyTopLevelOptionalElement().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TImport }
     * {@link TTypes }
     * {@link TMessage }
     * {@link TPortType }
     * {@link TBinding }
     * {@link TService }
     * 
     * 
     */
    public List<TDocumented> getAnyTopLevelOptionalElement() {
        if (anyTopLevelOptionalElement == null) {
            anyTopLevelOptionalElement = new ArrayList<TDocumented>();
        }
        return this.anyTopLevelOptionalElement;
    }

    /**
     * Gets the value of the targetNamespace property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetNamespace() {
        return targetNamespace;
    }

    /**
     * Sets the value of the targetNamespace property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTargetNamespace(String value) {
        this.targetNamespace = value;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    public void setAnyTopLevelOptionalElement(List<TDocumented> value) {
        this.anyTopLevelOptionalElement = null;
        if (value!= null) {
            List<TDocumented> draftl = this.getAnyTopLevelOptionalElement();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(object)) {
            return false;
        }
        final TDefinitions that = ((TDefinitions) object);
        {
            List<TDocumented> leftAnyTopLevelOptionalElement;
            leftAnyTopLevelOptionalElement = (((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty()))?this.getAnyTopLevelOptionalElement():null);
            List<TDocumented> rightAnyTopLevelOptionalElement;
            rightAnyTopLevelOptionalElement = (((that.anyTopLevelOptionalElement!= null)&&(!that.anyTopLevelOptionalElement.isEmpty()))?that.getAnyTopLevelOptionalElement():null);
            if ((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty())) {
                if ((that.anyTopLevelOptionalElement!= null)&&(!that.anyTopLevelOptionalElement.isEmpty())) {
                    if (!leftAnyTopLevelOptionalElement.equals(rightAnyTopLevelOptionalElement)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.anyTopLevelOptionalElement!= null)&&(!that.anyTopLevelOptionalElement.isEmpty())) {
                    return false;
                }
            }
        }
        {
            String leftTargetNamespace;
            leftTargetNamespace = this.getTargetNamespace();
            String rightTargetNamespace;
            rightTargetNamespace = that.getTargetNamespace();
            if (this.targetNamespace!= null) {
                if (that.targetNamespace!= null) {
                    if (!leftTargetNamespace.equals(rightTargetNamespace)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.targetNamespace!= null) {
                    return false;
                }
            }
        }
        {
            String leftName;
            leftName = this.getName();
            String rightName;
            rightName = that.getName();
            if (this.name!= null) {
                if (that.name!= null) {
                    if (!leftName.equals(rightName)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.name!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        currentHashCode = ((currentHashCode* 31)+ super.hashCode());
        {
            currentHashCode = (currentHashCode* 31);
            List<TDocumented> theAnyTopLevelOptionalElement;
            theAnyTopLevelOptionalElement = (((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty()))?this.getAnyTopLevelOptionalElement():null);
            if ((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty())) {
                currentHashCode += theAnyTopLevelOptionalElement.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theTargetNamespace;
            theTargetNamespace = this.getTargetNamespace();
            if (this.targetNamespace!= null) {
                currentHashCode += theTargetNamespace.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theName;
            theName = this.getName();
            if (this.name!= null) {
                currentHashCode += theName.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<TDocumented> theAnyTopLevelOptionalElement;
            theAnyTopLevelOptionalElement = (((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty()))?this.getAnyTopLevelOptionalElement():null);
            strategy.appendField(locator, this, "anyTopLevelOptionalElement", buffer, theAnyTopLevelOptionalElement, ((this.anyTopLevelOptionalElement!= null)&&(!this.anyTopLevelOptionalElement.isEmpty())));
        }
        {
            String theTargetNamespace;
            theTargetNamespace = this.getTargetNamespace();
            strategy.appendField(locator, this, "targetNamespace", buffer, theTargetNamespace, (this.targetNamespace!= null));
        }
        {
            String theName;
            theName = this.getName();
            strategy.appendField(locator, this, "name", buffer, theName, (this.name!= null));
        }
        return buffer;
    }

}
